﻿# Function to get the latest version from a registry key
function Get-LatestVersion {
    param (
        [string]$softwareKeyPath
    )

    $latestVersionRegistryValueName = "CURRENT_VERSION"

    # Use reg query to get the latest version from the registry
    $latestVersion = Get-ItemPropertyValue -Path $softwareKeyPath -Name $latestVersionRegistryValueName -ErrorAction SilentlyContinue

    if (-not [string]::IsNullOrWhiteSpace($latestVersion)) {
        return "$softwareKeyPath\$latestVersion"
    }

    return $null
}

# Specify the main registry key path for finding and replacing
$mainFindReplaceRegistryPath = "HKLM:\Software\Hexagon\NCSIMUL"
$findReplaceRegistryValueName = "REPUSERS"

# Get the latest version path
$latestVersionFindReplaceRegistryPath = Get-LatestVersion -softwareKeyPath $mainFindReplaceRegistryPath

if ($latestVersionFindReplaceRegistryPath -ne $null) {
    # Use reg query to get the find-and-replace string from the registry
    $findReplaceString = Get-ItemPropertyValue -Path $latestVersionFindReplaceRegistryPath -Name $findReplaceRegistryValueName

    # Check if the find-and-replace string is not null or empty
    if (-not [string]::IsNullOrWhiteSpace($findReplaceString)) {
        # Specify the path to the text file
        $filePath = ".\working_env.lst"

        # Read the content of the file
        $fileContent = Get-Content -Path $filePath -Raw

        # Escape special characters in the find-and-replace string
        $escapedFindReplaceString = [regex]::Escape("C:\ProgramData\Hexagon\NCSIMUL\Projects\")

        # Perform the find-and-replace operation
        $modifiedContent = $fileContent -replace $escapedFindReplaceString, $findReplaceString

        # Write the modified content back to the file
        $modifiedContent | Set-Content -Path $filePath -Force

        Write-Host "String replaced successfully in the file: $filePath"
    } else {
        Write-Host "Find-and-replace string not found or empty."
    }
}

# Specify the main registry key path for file copy
$mainRegistryKeyPath = "HKLM:\Software\Hexagon\NCSIMUL"
$registryValueName = "REPUSERS"

# Get the latest version path
$latestVersionRegistryKeyPath = Get-LatestVersion -softwareKeyPath $mainRegistryKeyPath

if ($latestVersionRegistryKeyPath -ne $null) {
    # Use reg query to get the registry value
    $registryValue = Get-ItemPropertyValue -Path $latestVersionRegistryKeyPath -Name $registryValueName

    # Check if the registry value is not null or empty
    if (-not [string]::IsNullOrWhiteSpace($registryValue)) {
        # Specify the source file path
        $sourceFilePath = ".\working_env.lst"

        # Specify the destination folder using the registry value
        $destinationFolderPath = Join-Path $registryValue ""

        # Create the destination folder if it doesn't exist
        if (-not (Test-Path -Path $destinationFolderPath)) {
            New-Item -Path $destinationFolderPath -ItemType Directory
        }

        # Specify the destination file path
        $destinationFilePath = Join-Path $destinationFolderPath "working_env.lst"

        # Copy the file to the new destination
        Copy-Item -Path $sourceFilePath -Destination $destinationFilePath -Force

        Write-Host "File copied successfully to: $destinationFilePath"
    } else {
        Write-Host "Registry value not found or empty."
    }
}
